@@ -180,15 +180,16 @@ def show_images_list(name, images_list, delay=0):
     cv2.waitKey(delay)
 
 
-def resize_image_like(image_list, dst_img):
+def resize_image_like(image_list, dst_img, is_rgb=False):
     """
     按dst_img的图像大小对image_list所有图片进行resize
     :param image_list: 图片列表
     :param dst_img: 目标图片大小
+    :param is_rgb: 是否将灰度图转换为RGB格式
     :return:
     """
     shape = dst_img.shape
-    is_rgb = len(shape) == 3
+    is_rgb = len(shape) == 3 or is_rgb
     for i in range(len(image_list)):
         if not shape[:2] == image_list[i].shape[:2]:
             image_list[i] = cv2.resize(image_list[i], dsize=(shape[1], shape[0]), interpolation=cv2.INTER_NEAREST)
@@ -197,9 +198,9 @@ def resize_image_like(image_list, dst_img):
     return image_list
 
 
-def image_hstack(images, split_line=False):
+def image_hstack(images, split_line=False, is_rgb=False):
     """图像左右拼接"""
-    dst_images = resize_image_like(image_list=images, dst_img=images[0])
+    dst_images = resize_image_like(image_list=images, dst_img=images[0], is_rgb=is_rgb)
     dst_images = np.hstack(dst_images)
     if len(dst_images.shape) == 2:
         dst_images = cv2.cvtColor(dst_images, cv2.COLOR_GRAY2BGR)
@@ -214,9 +215,9 @@ def image_hstack(images, split_line=False):
     return dst_images
 
 
-def image_vstack(images, split_line=False):
+def image_vstack(images, split_line=False, is_rgb=False):
     """图像上下拼接"""
-    dst_images = resize_image_like(image_list=images, dst_img=images[0])
+    dst_images = resize_image_like(image_list=images, dst_img=images[0], is_rgb=is_rgb)
     dst_images = np.vstack(dst_images)
     if len(dst_images.shape) == 2:
         dst_images = cv2.cvtColor(dst_images, cv2.COLOR_GRAY2BGR)
@@ -453,7 +454,7 @@ def requests_url(url):
     return stream
 
 
-def read_images_url(url, size=None, normalization=False, use_rgb='RGB'):
+def read_images_url(url, size=None, normalization=False, use_rgb=True):
     """
     根据url或者图片路径，读取图片
     :param url:
@@ -827,7 +828,6 @@ def scale_rect(orig_rect, orig_shape, dest_shape):
     return dest_rect
 
 
-
 def xyxy2xywh(xyxy: np.ndarray):
     """(xmin,ymin,xmax,ymax)==>(xmin,ymin,w,h)"""
     xywh = xyxy.copy()
@@ -895,7 +895,6 @@ def extend_xywh(xywh: np.ndarray, scale=[1.0, 1.0]):
     return dxywh
 
 
-
 def get_rect_intersection(rec1, rec2):
     """
     计算两个rect的交集坐标
@@ -972,7 +971,7 @@ def show_image_boxes(title, image, boxes_list, color=(0, 0, 255), delay=0):
     return image
 
 
-def draw_image_bboxes_text(rgb_image, boxes, boxes_name, color, drawType="custom", top=True):
+def draw_image_bboxes_text(rgb_image, boxes, boxes_name, color, thickness=2, drawType="custom", top=True):
     """
     :param boxes_name:
     :param bgr_image: bgr image
@@ -989,11 +988,12 @@ def draw_image_bboxes_text(rgb_image, boxes, boxes_name, color, drawType="custom
         # cv2.putText(bgr_image, name, (crop_type[0], crop_type[1]), cv2.FONT_HERSHEY_SIMPLEX, 0.8, (0, 0, 255), thickness=2)
         # cv2.rectangle(bgr_image, (crop_type[0], crop_type[1]), (crop_type[2], crop_type[3]), color, 2, 8, 0)
         # cv2.putText(bgr_image, str(name), (crop_type[0], crop_type[1]), cv2.FONT_HERSHEY_SIMPLEX, 0.8, color, thickness=2)
-        custom_bbox_line(rgb_image, box, color, name, drawType, top)
+        custom_bbox_line(rgb_image, box, color, name, thickness, drawType, top)
     return rgb_image
 
 
-def draw_image_bboxes_labels_text(rgb_image, boxes, labels, boxes_name=None, color=None, drawType="custom", top=True):
+def draw_image_bboxes_labels_text(rgb_image, boxes, labels, boxes_name=None, color=None, thickness=2, drawType="custom",
+                                  top=True):
     """
     :param rgb_image:
     :param boxes:
@@ -1011,7 +1011,7 @@ def draw_image_bboxes_labels_text(rgb_image, boxes, labels, boxes_name=None, col
     for label, box, name in zip(labels, boxes, boxes_name):
         box = [int(b) for b in box]
         color_ = color if color else color_map[int(label)]
-        custom_bbox_line(rgb_image, box, color_, str(name), drawType, top)
+        custom_bbox_line(rgb_image, box, color_, str(name), thickness, drawType, top)
     return rgb_image
 
 
@@ -1090,7 +1090,7 @@ def flat_data(data):
     return data
 
 
-def draw_image_detection_bboxes(rgb_image, bboxes, probs, labels, class_name=None):
+def draw_image_detection_bboxes(rgb_image, bboxes, probs, labels, class_name=None, thickness=2):
     """
     :param title:
     :param rgb_image:
@@ -1107,7 +1107,7 @@ def draw_image_detection_bboxes(rgb_image, bboxes, probs, labels, class_name=Non
         if class_name:
             label = class_name[int(label)]
         boxes_name = "{}:{:3.3f}".format(label, prob)
-        custom_bbox_line(rgb_image, box, color, boxes_name, drawType="custom")
+        custom_bbox_line(rgb_image, box, color, boxes_name, thickness, drawType="custom")
     return rgb_image
 
 
@@ -1149,7 +1149,7 @@ def draw_dt_gt_dets(image, dt_boxes, dt_label, gt_boxes, gt_label, vis_diff=Fals
     return image
 
 
-def custom_bbox_line(image, bbox, color, name, drawType="custom", top=True):
+def custom_bbox_line(image, bbox, color, name, thickness=2, drawType="custom", top=True):
     """
     :param image:
     :param bbox:
@@ -1160,7 +1160,6 @@ def custom_bbox_line(image, bbox, color, name, drawType="custom", top=True):
     :return:
     """
     fontScale = 0.5
-    thickness = 1
     if not name:
         drawType = "simple"
     if drawType == "simple":
@@ -1561,13 +1560,23 @@ def pil_paste_image(im, mask, start_point=(0, 0)):
     return np.asarray(out)
 
 
-def cv_rotate(image, angle, center=None, scale=1.0):  # 1
-    (h, w) = image.shape[:2]  # 2
-    if center is None:  # 3
-        center = (w // 2, h // 2)  # 4
-    M = cv2.getRotationMatrix2D(center, angle, scale)  # 5
-    rotated = cv2.warpAffine(image, M, (w, h))  # 6
-    return rotated  # 7
+def image_rotation(image, angle, center=None, scale=1.0, borderValue=(0, 0, 0)):
+    """
+    图像旋转
+    :param image:
+    :param angle:
+    :param center:
+    :param scale:
+    :param borderValue:
+    :return:
+    """
+    h, w = image.shape[:2]
+    if not center:
+        # center = (w // 2, h // 2)
+        center = (w / 2., h / 2.)
+    mat = cv2.getRotationMatrix2D(center, angle, scale)
+    rotated = cv2.warpAffine(image, mat, dsize=(w, h), borderMode=cv2.BORDER_CONSTANT, borderValue=borderValue)
+    return rotated
 
 
 def rgb_to_gray(image):
@@ -1827,10 +1836,10 @@ def get_rect_crop_padding(image, rect, color=(0, 0, 0)):
     roi_image = image[crop_y1:crop_y2, crop_x1:crop_x2]
     # 只要存在边界越界的情况，就需要边界填充
     if top_y > 0 or down_y > 0 or left_x > 0 or right_x > 0:
-        left_x = np.where(left_x > 0, left_x, 0)
-        right_x = np.where(right_x > 0, right_x, 0)
-        top_y = np.where(top_y > 0, top_y, 0)
-        down_y = np.where(down_y > 0, down_y, 0)
+        left_x = max(left_x, 0)
+        right_x = max(right_x, 0)
+        top_y = max(top_y, 0)
+        down_y = max(0, down_y, 0)
         roi_image = cv2.copyMakeBorder(roi_image, int(top_y), int(down_y), int(left_x), int(right_x),
                                        cv2.BORDER_CONSTANT, value=color)
     return roi_image
@@ -1906,15 +1915,15 @@ def center_crop(image, crop_size=[112, 112]):
     """
     central_crop
     :param image: input numpy type image
-    :param crop_size:crop_size must less than x.shape[:2]=[crop_h,crop_w]
+    :param crop_size: (W,H) crop_size must less than x.shape[:2]=[crop_h,crop_w]
     :return:
     """
     h, w = image.shape[:2]
-    y = int(round((h - crop_size[0]) / 2.))
-    x = int(round((w - crop_size[1]) / 2.))
+    y = int(round((h - crop_size[1]) / 2.))
+    x = int(round((w - crop_size[0]) / 2.))
     y = max(y, 0)
     x = max(x, 0)
-    return image[y:y + crop_size[0], x:x + crop_size[1]]
+    return image[y:y + crop_size[1], x:x + crop_size[0]]
 
 
 def center_crop_padding(image, crop_size, color=(0, 0, 0)):
@@ -2152,6 +2161,29 @@ def get_contours_iou(contour1, contour2, image_size: Tuple = None, plot=False):
     return contours, iou
 
 
+def get_mask_iou(mask1, mask2, binarize=True):
+    """
+    计算两个Mask的IOU
+    :param mask1:
+    :param mask2:
+    :param binarize:
+    :return:
+    """
+    if binarize:
+        ret, mask1 = cv2.threshold(mask1, 0, 255, cv2.THRESH_BINARY | cv2.THRESH_OTSU)
+        ret, mask2 = cv2.threshold(mask2, 0, 255, cv2.THRESH_BINARY | cv2.THRESH_OTSU)
+    h, w = mask1.shape[:2]
+    mask2 = cv2.resize(mask2, dsize=(w, h), interpolation=cv2.INTER_NEAREST)
+    mask1 = mask1 >= 255
+    mask2 = mask2 >= 255
+    area1 = mask1.sum()
+    area2 = mask2.sum()
+    inter = mask1 * mask2
+    inter_ = (inter == 1).sum()  # 交集
+    iou = inter_ / (area1 + area2 - inter_)
+    return iou
+
+
 def pointPolygonTest(point, contour, measureDist=False):
     """
     此功能可查找图像中的点与轮廓之间的最短距离.
@@ -2181,7 +2213,7 @@ def draw_image_contours(image, contours: List[np.ndarray], color=(0, 255, 0), th
     return image
 
 
-def get_mask_boundrect_cv(mask, binarize=False, shift=True):
+def get_mask_boundrect_cv(mask, binarize=False, shift=0):
     """
     获得mask的最大外接矩形框(其速度比get_mask_boundrect快2倍左右)
     :param mask:
@@ -2198,10 +2230,10 @@ def get_mask_boundrect_cv(mask, binarize=False, shift=True):
     ymin = np.min(contours[:, 1])
     xmax = np.max(contours[:, 0])
     ymax = np.max(contours[:, 1])
-    xmin = max(0, xmin - shift)
-    ymin = max(0, ymin - shift)
-    xmax = min(w, xmax + shift)
-    ymax = min(h, ymax + shift)
+    xmin = max(0, int(xmin - shift))
+    ymin = max(0, int(ymin - shift))
+    xmax = min(w, int(xmax + shift))
+    ymax = min(h, int(ymax + shift))
     return [xmin, ymin, xmax, ymax]
 
 
@@ -2230,10 +2262,10 @@ def get_mask_boundrect(mask, binarize=False, shift=0):
     x = x > 0
     ymin, ymax = get_argminmax(y)
     xmin, xmax = get_argminmax(x)
-    xmin = max(0, xmin - shift)
-    ymin = max(0, ymin - shift)
-    xmax = min(w, xmax + shift)
-    ymax = min(h, ymax + shift)
+    xmin = max(0, int(xmin - shift))
+    ymin = max(0, int(ymin - shift))
+    xmax = min(w, int(xmax + shift))
+    ymax = min(h, int(ymax + shift))
     return [xmin, ymin, xmax, ymax]
 
 
@@ -2348,29 +2380,6 @@ class EventCv():
         cv2.setMouseCallback(winname, callbackFunc, param=param)
 
 
-def get_video_capture(video_path, width=None, height=None, fps=None):
-    """
-     --   7W   Pix--> width=320,height=240
-     --   30W  Pix--> width=640,height=480
-     720P,100W Pix--> width=1280,height=720
-     960P,130W Pix--> width=1280,height=1024
-    1080P,200W Pix--> width=1920,height=1080
-    :param video_path:
-    :param width:
-    :param height:
-    :return:
-    """
-    video_cap = cv2.VideoCapture(video_path)
-    # 设置分辨率
-    if width:
-        video_cap.set(cv2.CAP_PROP_FRAME_WIDTH, width)
-    if height:
-        video_cap.set(cv2.CAP_PROP_FRAME_HEIGHT, height)
-    if fps:
-        video_cap.set(cv2.CAP_PROP_FPS, 15)
-    return video_cap
-
-
 def get_image_block(image, grid=[3, 3], same=False):
     """
     :param image:
@@ -2495,6 +2504,29 @@ def image_file_list2gif(file_list, size=None, gif_file="test.gif", fps=4, loop=0
     # images2gif_by_imageio(frames,gif_file, fps=fps, loop=loop)
 
 
+def get_video_capture(video_path, width=None, height=None, fps=None):
+    """
+     --   7W   Pix--> width=320,height=240
+     --   30W  Pix--> width=640,height=480
+     720P,100W Pix--> width=1280,height=720
+     960P,130W Pix--> width=1280,height=1024
+    1080P,200W Pix--> width=1920,height=1080
+    :param video_path:
+    :param width:
+    :param height:
+    :return:
+    """
+    video_cap = cv2.VideoCapture(video_path)
+    # 设置分辨率
+    if width:
+        video_cap.set(cv2.CAP_PROP_FRAME_WIDTH, width)
+    if height:
+        video_cap.set(cv2.CAP_PROP_FRAME_HEIGHT, height)
+    if fps:
+        video_cap.set(cv2.CAP_PROP_FPS, 15)
+    return video_cap
+
+
 def get_video_info(video_cap):
     width = int(video_cap.get(cv2.CAP_PROP_FRAME_WIDTH))
     height = int(video_cap.get(cv2.CAP_PROP_FRAME_HEIGHT))
