@@ -8,7 +8,7 @@
 import cv2
 import numpy as np
 from typing import List, Tuple, Dict
-from pybaseutils import image_utils, json_utils
+from pybaseutils import image_utils, json_utils, file_utils
 
 
 def concat_stroke_image(mask, seg_list, split_line=False, vis=False):
@@ -155,7 +155,7 @@ def find_key_metadata(metadata: List[Dict], key):
     return values
 
 
-def show_word_packer(packer, image, keys=[], delay=0):
+def show_word_packer(packer, image, keys=[], split_line=False, color=(0, 0, 255), thickness=2, delay=0):
     _keys = ['label', 'cls_score', 'box', 'det_score']
     for word in packer:
         label = word['label'] if "label" in word else ""
@@ -163,13 +163,17 @@ def show_word_packer(packer, image, keys=[], delay=0):
         info = ["{}:{}".format(k, word[k]) for k in _keys if k in word]
         print(info)
         if isinstance(image, np.ndarray):
-            image = image_utils.draw_image_bboxes_text(image, boxes=[word["box"]],
-                                                       boxes_name=[label], color=(0, 0, 255))
-            show_image("dets", [image], delay=1)
-        show_image("packer", images, delay=delay)
+            image = image_utils.draw_image_bboxes_text(image,
+                                                       boxes=[word["box"]],
+                                                       boxes_name=[label],
+                                                       color=color,
+                                                       thickness=thickness)
+            show_images("dets", [image], split_line=split_line, delay=1)
+        show_images("packer", images, split_line=split_line, delay=delay)
+    return image
 
 
-def show_word_unpacker(unpacker, image, keys=[], delay=0):
+def show_word_unpacker(unpacker, image, keys=[], split_line=False, color=(0, 0, 255), thickness=2, delay=0):
     _keys = ['label', 'cls_score', 'box', 'det_score']
     for i in range(len(unpacker["box"])):
         label = unpacker["label"][i] if "label" in unpacker else ""
@@ -177,14 +181,36 @@ def show_word_unpacker(unpacker, image, keys=[], delay=0):
         info = ["{}:{}".format(k, unpacker[k][i]) for k in _keys if k in unpacker]
         print(info)
         if isinstance(image, np.ndarray):
-            image = image_utils.draw_image_bboxes_text(image, boxes=[unpacker["box"][i]],
-                                                       boxes_name=[label], color=(0, 0, 255))
-            show_image("dets", [image], delay=1)
-        show_image("unpacker", images, delay=delay)
+            image = image_utils.draw_image_bboxes_text(image,
+                                                       boxes=[unpacker["box"][i]],
+                                                       boxes_name=[label],
+                                                       color=color,
+                                                       thickness=thickness)
+            show_images("dets", [image], split_line=split_line, delay=1)
+        show_images("unpacker", images, split_line=split_line, delay=delay)
+    return image
 
 
-def show_image(title, images, use_rgb=False, delay=0):
+def show_images(title, images, use_rgb=False, split_line=False, delay=0):
     if isinstance(images, np.ndarray): images = [images]
     if len(images) == 0: return
-    image = image_utils.image_hstack(images)
+    image = image_utils.image_hstack(images, split_line=split_line)
     image_utils.cv_show_image(title, image, use_rgb=use_rgb, delay=delay)
+
+
+def save_images(images, dsize=None, out_dir="./output"):
+    for img in images:
+        name = file_utils.get_time("p") + ".png"
+        file = file_utils.create_dir(out_dir, None, name)
+        img = image_utils.resize_image(img, size=dsize)
+        cv2.imwrite(file, img)
+
+
+def save_packer_images(packer, keys=["crop"], dsize=None, out_dir="./output"):
+    for i, word in enumerate(packer):
+        time = file_utils.get_time("p")
+        for k in keys:
+            name = "{:0=3d}_{}_{}.png".format(i, time, k)
+            file = file_utils.create_dir(out_dir, None, name)
+            img = image_utils.resize_image(word[k], size=dsize)
+            cv2.imwrite(file, img)
